@@ -1,18 +1,21 @@
 #pragma once
+
+#ifdef USE_ESP32
 #include "esphome/core/component.h"
 #include "esphome/core/helpers.h"
 
 #include <queue>
 #include <mutex>
-
-#ifdef ARDUINO_ARCH_ESP32
+#include <cstring>
 
 #include <esp_gap_ble_api.h>
 #include <esp_gattc_api.h>
+#include <freertos/FreeRTOS.h>
+#include <freertos/semphr.h>
 
 /*
  * BLE events come in from a separate Task (thread) in the ESP32 stack. Rather
- * than trying to deal wth various locking strategies, all incoming GAP and GATT
+ * than trying to deal with various locking strategies, all incoming GAP and GATT
  * events will simply be placed on a semaphore guarded queue. The next time the
  * component runs loop(), these events are popped off the queue and handed at
  * this safer time.
@@ -23,33 +26,33 @@ namespace esp32_ble_tracker {
 
 template<class T> class Queue {
  public:
-  Queue() { m = xSemaphoreCreateMutex(); }
+  Queue() { m_ = xSemaphoreCreateMutex(); }
 
   void push(T *element) {
     if (element == nullptr)
       return;
-    if (xSemaphoreTake(m, 5L / portTICK_PERIOD_MS)) {
-      q.push(element);
-      xSemaphoreGive(m);
+    if (xSemaphoreTake(m_, 5L / portTICK_PERIOD_MS)) {
+      q_.push(element);
+      xSemaphoreGive(m_);
     }
   }
 
   T *pop() {
     T *element = nullptr;
 
-    if (xSemaphoreTake(m, 5L / portTICK_PERIOD_MS)) {
-      if (!q.empty()) {
-        element = q.front();
-        q.pop();
+    if (xSemaphoreTake(m_, 5L / portTICK_PERIOD_MS)) {
+      if (!q_.empty()) {
+        element = q_.front();
+        q_.pop();
       }
-      xSemaphoreGive(m);
+      xSemaphoreGive(m_);
     }
     return element;
   }
 
  protected:
-  std::queue<T *> q;
-  SemaphoreHandle_t m;
+  std::queue<T *> q_;
+  SemaphoreHandle_t m_;
 };
 
 // Received GAP and GATTC events are only queued, and get processed in the main loop().
@@ -84,12 +87,12 @@ class BLEEvent {
   };
 
   union {
-    struct gap_event {
+    struct gap_event {  // NOLINT(readability-identifier-naming)
       esp_gap_ble_cb_event_t gap_event;
       esp_ble_gap_cb_param_t gap_param;
     } gap;
 
-    struct gattc_event {
+    struct gattc_event {  // NOLINT(readability-identifier-naming)
       esp_gattc_cb_event_t gattc_event;
       esp_gatt_if_t gattc_if;
       esp_ble_gattc_cb_param_t gattc_param;
