@@ -2,6 +2,7 @@
 
 #include "esphome/core/defines.h"
 
+#ifdef USE_MQTT
 #ifdef USE_CLIMATE
 
 #include "esphome/components/climate/climate.h"
@@ -15,7 +16,6 @@ class MQTTClimateComponent : public mqtt::MQTTComponent {
   MQTTClimateComponent(climate::Climate *device);
   void send_discovery(JsonObject &root, mqtt::SendDiscoveryConfig &config) override;
   bool send_initial_state() override;
-  bool is_internal() override;
   std::string component_type() const override;
   void setup() override;
 
@@ -30,9 +30,14 @@ class MQTTClimateComponent : public mqtt::MQTTComponent {
   MQTT_COMPONENT_CUSTOM_TOPIC(target_temperature_high, command)
   MQTT_COMPONENT_CUSTOM_TOPIC(away, state)
   MQTT_COMPONENT_CUSTOM_TOPIC(away, command)
+  MQTT_COMPONENT_CUSTOM_TOPIC(action, state)
+  MQTT_COMPONENT_CUSTOM_TOPIC(fan_mode, state)
+  MQTT_COMPONENT_CUSTOM_TOPIC(fan_mode, command)
+  MQTT_COMPONENT_CUSTOM_TOPIC(swing_mode, state)
+  MQTT_COMPONENT_CUSTOM_TOPIC(swing_mode, command)
 
  protected:
-  std::string friendly_name() const override;
+  const EntityBase *get_entity() const override;
 
   bool publish_state_();
 
@@ -43,3 +48,4 @@ class MQTTClimateComponent : public mqtt::MQTTComponent {
 }  // namespace esphome
 
 #endif
+#endif  // USE_MQTT
