@@ -6,25 +6,21 @@ from esphome.components import mqtt
 from esphome.const import (
     CONF_ABOVE,
     CONF_BELOW,
-    CONF_DISABLED_BY_DEFAULT,
-    CONF_ICON,
     CONF_ID,
-    CONF_INTERNAL,
     CONF_ON_VALUE,
     CONF_ON_VALUE_RANGE,
     CONF_TRIGGER_ID,
-    CONF_NAME,
     CONF_MQTT_ID,
     CONF_VALUE,
-    ICON_EMPTY,
 )
 from esphome.core import CORE, coroutine_with_priority
+from esphome.cpp_helpers import setup_entity
 
 CODEOWNERS = ["@esphome/core"]
 IS_PLATFORM_COMPONENT = True
 
 number_ns = cg.esphome_ns.namespace("number")
-Number = number_ns.class_("Number", cg.Nameable)
+Number = number_ns.class_("Number", cg.EntityBase)
 NumberPtr = Number.operator("ptr")
 
 # Triggers
@@ -45,12 +41,10 @@ NumberInRangeCondition = number_ns.class_(
 
 icon = cv.icon
 
-
-NUMBER_SCHEMA = cv.NAMEABLE_SCHEMA.extend(cv.MQTT_COMPONENT_SCHEMA).extend(
+NUMBER_SCHEMA = cv.ENTITY_BASE_SCHEMA.extend(cv.MQTT_COMMAND_COMPONENT_SCHEMA).extend(
     {
         cv.OnlyWith(CONF_MQTT_ID, "mqtt"): cv.declare_id(mqtt.MQTTNumberComponent),
         cv.GenerateID(): cv.declare_id(Number),
-        cv.Optional(CONF_ICON, default=ICON_EMPTY): icon,
         cv.Optional(CONF_ON_VALUE): automation.validate_automation(
             {
                 cv.GenerateID(CONF_TRIGGER_ID): cv.declare_id(NumberStateTrigger),
@@ -71,12 +65,8 @@ NUMBER_SCHEMA = cv.NAMEABLE_SCHEMA.extend(cv.MQTT_COMPONENT_SCHEMA).extend(
 async def setup_number_core_(
     var, config, *, min_value: float, max_value: float, step: Optional[float]
 ):
-    cg.add(var.set_name(config[CONF_NAME]))
-    cg.add(var.set_disabled_by_default(config[CONF_DISABLED_BY_DEFAULT]))
-    if CONF_INTERNAL in config:
-        cg.add(var.set_internal(config[CONF_INTERNAL]))
+    await setup_entity(var, config)
 
-    cg.add(var.traits.set_icon(config[CONF_ICON]))
     cg.add(var.traits.set_min_value(min_value))
     cg.add(var.traits.set_max_value(max_value))
     if step is not None:
